<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\Session\Session;
use Zeedhi\Framework\DTO\Response\Message;
use \Setforms2\Shared\ORM\DateTime;
use Teknisa\MAN\Utilities\Util;
use Teknisa\MAN\Services\ParamsProduto as ParamsProdutoService;


class TabelaPrecoGeral extends \Teknisa\MAN\Controllers\TeknisaCrud  {
    
    protected $dataSourceManager;
    protected $dataSourceName = 'vnd42700_tabelaprecoGeral';
    protected $crudService;
    protected $environment;
    protected $TabelaPrecoService;
    protected $paramsProdutoService;
    protected $utilService;
    
    public function __construct($dataSourceManager, $crudService, $environment, $TabelaPrecoService, ParamsProdutoService $paramsProdutoService, Util $utilService) {
        $this->dataSourceManager    = $dataSourceManager;
        $this->crudService          = $crudService;
        $this->environment          = $environment;
        $this->TabelaPrecoService   = $TabelaPrecoService;
        $this->paramsProdutoService = $paramsProdutoService;
        $this->util                 = $utilService;
    }

    public function findVigencias(DTO\Request $request, DTO\Response $response){
        $params = $this->util->getParamsAsArray($request);
        $return = $this->TabelaPrecoService->findVigencias($params);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd42700_tabelaprecoGeral', $return));
    }
    
    public function findUnidades(DTO\Request $request, DTO\Response $response){
        $params = $this->util->getParamsAsArray($request);
        
        $return = $this->TabelaPrecoService->findUnidades($params);
        
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd42700_tabelaprecoGeral_unidade', $return));
    }
    
    public function saveUnidades(DTO\Request $request, DTO\Response $response){
        $params = $this->util->getParamsAsArray($request);
        return $this->TabelaPrecoService->saveUnidades($params[0]);
    }
    
    public function findPrecoDiferenciado(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "vnd42700_tabelaprecoGeral_precodiferenciado";
        parent::find($request,$response);
    }
    
    public function deleteVigencia(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
        $CDTABEPREC      = $row[0]['CDTABEPREC'];
        $DTINIVGPREC     = $row[0]['DTINIVGPREC'];
        $DTFINVGPREC     = $row[0]['DTFINVGPREC'];
        $NRORG           = $this->environment->getNrOrgTrab();
        $this->TabelaPrecoService->deleteVigencia($NRORG,$CDTABEPREC,$DTINIVGPREC);
        if($DTINIVGPREC == null && $DTFINVGPREC == null){
            $this->deleteTabelaPreco($request,$response);
            $this->TabelaPrecoService->deleteFilialTabelaPreco($row[0]);
            
        }
    }
    
    public function deleteUnidade(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        $this->TabelaPrecoService->deleteUnidade($rows);
    }
    
    public function findProduto(DTO\Request $request, DTO\Response $response) {
        $params = $this->util->getParamsAsArray($request);
        $return = $this->TabelaPrecoService->findProdutos($params);
        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd42700_tabelaprecoGeral_produto', $return));
    }    
      
    
    public function findComposicaoProduto(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "vnd42400_tabelapreco_composicaoproduto";
        parent::find($request,$response);
    }
    
    
    public function findVigenciasImport(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getFilterCriteria()->getConditions();
            $Res = $this->TabelaPrecoService->findVigenciasImport($row);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd42400_tabelapreco_vigencias_import', $Res));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function validImportPriceChart(DTO\Request $request, DTO\Response $response){
        try {
            $row = $request->getFilterCriteria()->getConditions();
            $Res = $this->TabelaPrecoService->validImportPriceChart($row);
            
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('vnd42400_validImportPriceChart', $Res));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function importItensVigencia(DTO\Request $request, DTO\Response $response){
        try {
            
            $row = $request->getFilterCriteria()->getConditions();
            $this->TabelaPrecoService->importItensVigencia($row);
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findMercado(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "vnd42400_tabelapreco_mercado";
        parent::find($request,$response);
    }
    
    public function saveTabelaPreco(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "vnd42400_tabelapreco";
        $row = $request->getDataSet()->getRows();
        
        $currentTime = new \DateTime(null,new \DateTimeZone('America/Sao_Paulo'));
        $isNew = $row[0]['__is_new'];
        $IDATIVO        = 'S';
        if($isNew){
            $CDOPERINCLUSAO = $this->environment->getCdOperador();
            $DTINCLUSAO     = $currentTime->format("d/m/Y");
            $NRORGINCLUSAO  = $this->environment->getNrOrgTrab();
        }
        $NRORG          = $this->environment->getNrOrgTrab();
        $CDOPERULTATU   = $this->environment->getCdOperador();
        $DTULTATU       = $currentTime->format("d/m/Y");
        $NRORGULTATU    = $this->environment->getNrOrgTrab();
        $NMTABEPREC     = $row[0]['NMTABEPREC'];
        $CDTABEPREC     = $row[0]['CDTABEPREC'];
        $CDFILIAL       = $row[0]['CDFILIAL'];
        if($isNew){
            $this->TabelaPrecoService->insertTabelaPreco($CDFILIAL,$CDTABEPREC,$NMTABEPREC,$IDATIVO,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDOPERINCLUSAO,$DTINCLUSAO,$NRORG,$NRORGINCLUSAO);
            $response->addNotification(new Notification("Tabela de preço {$NMTABEPREC} adicionada com sucesso!", Notification::TYPE_SUCCESS));
        } else
           parent::save($request, $response);
    }
    
    public function deleteTabelaPreco(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = "vnd42700_tabelaprecoGeral";
        $row = $request->getDataSet()->getRows();
        $NMTABEPREC     = $row[0]['NMTABEPREC'];
        $CDTABEPREC     = $row[0]['CDTABEPREC'];
        $NRORG          = $this->environment->getNrOrgTrab();
            parent::delete($request, $response);
    }
    
    public function savePrecoDiferenciado(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        $currentTime = new \DateTime(null,new \DateTimeZone('America/Sao_Paulo'));
        foreach($rows as $key => &$row){
            $rows[$key]['HRFINPRECDIA'] = str_replace(':','',$rows[$key]['HRFINPRECDIA']);
            $rows[$key]['HRINIPRECDIA'] = str_replace(':','',$rows[$key]['HRINIPRECDIA']);
            $rows[$key]['VRPRECODIA'] = $this->valorBD($rows[$key]['VRPRECODIA']);
            $rows[$key]['VRPRECODIF'] = ($rows[$key]['VRPRECODIF']);
            $rows[$key]['CDOPERULTATU']   =   $this->environment->getCdOperador();
            $rows[$key]['CDOPERINCLUSAO']   =   $this->environment->getCdOperador();
            $rows[$key]['DTULTATU']       =   $currentTime->format("d/m/Y");
            $rows[$key]['DTINCLUSAO']       =   $currentTime->format("d/m/Y");
            unset($rows[$key]['DTFINVGPREC']);
        }
        
        if($rows[0]['__is_new']){
            $diasSemana = $rows[0]['NRDIASEMANPR'];
            $this->dataSourceName = "vnd42700_tabelaprecoGeral_precodiferenciado";
            foreach($diasSemana as $dia){
                $row->set('NRDIASEMANPR',$dia);
                if(!$this->TabelaPrecoService->verificaPrecoDifConsumidor($row)){
                    throw new \Exception("Tipo de consumidor não pode repetir no mesmo dia em um mesmo horário inicial!");
                }
                parent::save($request,$response);
            }
        } else {
            try{
                $CDTABEPREC     =   $row['CDTABEPREC'];
                $DTINIVGPREC    =   $row['DTINIVGPREC'];
                $CDPRODUTO      =   $row['CDPRODUTO'];
                $CDPRPAITABPR   =   $row['CDPRPAITABPR'];
                $NRDIASEMANPR   =   $row['NRDIASEMANPR'];
                $HRINIPRECDIA   =   $row['HRINIPRECDIA'];
                $HRFINPRECDIA   =   $row['HRFINPRECDIA'];
                $VRPRECODIA     =   $row['VRPRECODIA'];
                $IDPERVALORPR   =   $row['IDPERVALORPR'];
                $IDDESCACREPR   =   $row['IDDESCACREPR'];
                $DTINIVALPREC   =   $row['DTINIVALPREC'];
                $DTFINVALPREC   =   $row['DTFINVALPREC'];
                $CDTIPOCONSPD   =   $row['CDTIPOCONSPD'];
                $IDVISUACUPOM   =   $row['IDVISUACUPOM'];
                $NMTIPOCONS     =   $row['NMTIPOCONS'];
                $VRPRECODIF     =   $row['VRPRECODIF'];
                $NRORG          =   $this->environment->getNrOrgTrab();
                $CDOPERULTATU   =   $this->environment->getCdOperador();
                $DTULTATU       =   $currentTime->format("d/m/Y");
                $NRORGULTATU    =   $this->environment->getNrOrgTrab();
                
                $this->TabelaPrecoService->updatePrecoDiferenciado($CDTABEPREC,$DTINIVGPREC,$CDPRODUTO,$CDPRPAITABPR,$NRDIASEMANPR,$HRINIPRECDIA,$HRFINPRECDIA,$VRPRECODIA,$IDPERVALORPR,$IDDESCACREPR,$DTINIVALPREC,$DTFINVALPREC,$CDTIPOCONSPD,$IDVISUACUPOM,$NMTIPOCONS,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU, $VRPRECODIF);
                
            } catch(\Exception $e) {
                $response->setError(new DTO\Response\Error($e->getMessage(), 2));
            }
        }
    }
    
    public function saveVigencia(DTO\Request\DataSet $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows()[0];
        
        foreach($request->getDataSet()->getRows() as $key => &$row){
            $row['IDSITVGPREC'] = '1';
        
        }
        $NMTABEPREC     = $row['NMTABEPREC']; 
        $DTINIVGPREC    = $row['DTINIVGPREC'];
        $DTFINVGPREC    = $row['DTFINVGPREC'];
        
        $DTINIVG = strtotime(str_replace("/", "-", $DTINIVGPREC));
        $DTFINVG = strtotime(str_replace("/", "-", $DTFINVGPREC));
        
        if($DTINIVG > $DTFINVG){
            $response->addMessage(new Message("Data inicial não pode ser maior que data final de vigência.",Message::TYPE_ERROR));
            $response->setError(new DTO\Response\Error('Data inicial não pode ser maior que data final de vigência',1));
        } else{
            $this->dataSourceName = 'vnd42700_tabelaprecoGeral_vigencias';
            $CDTABEPREC     = $row['CDTABEPREC'];
            $currentTime = new \DateTime(null,new \DateTimeZone('America/Sao_Paulo'));
            if(!$row['GROUPED_LABEL'] || $row['__is_new']){  
               $VigenciaDateInterval = $this->TabelaPrecoService->getInsertValidVigenciaDate($CDTABEPREC);
            } else{
                if(strlen($row['OLD_DTINIVGPREC'])>10)
                    $OLD_DTINIVGPREC = $row['OLD_DTINIVGPREC'];
                else 
                    $OLD_DTINIVGPREC = $row['OLD_DTINIVGPREC'];
                if(strlen($row['OLD_DTFINVGPREC'])>10)    
                    $OLD_DTFINVGPREC = $row['OLD_DTFINVGPREC'];
                else 
                    $OLD_DTFINVGPREC = $row['OLD_DTFINVGPREC'];
                
                $VigenciaDateInterval = $this->TabelaPrecoService->getUpdateValidVigenciaDate($CDTABEPREC,$OLD_DTINIVGPREC,$OLD_DTFINVGPREC);
            }
            if(count($VigenciaDateInterval)>2){
                $MaxVigencia = end($VigenciaDateInterval);
            } else{
                $MaxVigencia = null;
            }
            foreach($VigenciaDateInterval as $key => $VigenciaDate){
                $INICIO =   date_create_from_format('d/m/Y h:i:s',$VigenciaDate['INICIO']);
                $FIM    =   date_create_from_format('d/m/Y h:i:s',$VigenciaDate['FIM']);
                if(($DTINIVGPREC > $INICIO) && ($DTINIVGPREC < $FIM) && ($VigenciaDate != $MaxVigencia)){
                    $response->addMessage(new Message("Não é possível salvar. Data inicial encontra-se entre uma vigência existente.",Message::TYPE_ERROR)); 
                    
                    return $response;
                } elseif(($DTFINVGPREC > $INICIO) && ($DTFINVGPREC < $FIM) && ($VigenciaDate != $MaxVigencia)){
                    $response->addMessage(new Message("Não é possível salvar. Data final encontra-se entre uma vigência existente.",Message::TYPE_ERROR)); 
                    
                    return $response;
                } elseif(($DTINIVGPREC < $INICIO) && ($DTFINVGPREC > $FIM)){
                    $response->addMessage(new Message("Não é possível salvar. Existe uma vigência entre as datas informadas.",Message::TYPE_ERROR)); 
                    
                    return $response;
                } 
            }
            
            if(!$row['GROUPED_LABEL']){
                $CDOPERINCLUSAO = $this->environment->getCdOperador();
                $DTINCLUSAO     = $currentTime->format("d/m/Y");
                $NRORGINCLUSAO  = $this->environment->getNrOrgTrab();
            }
            
            $NRORG          = $this->environment->getNrOrgTrab();
            $NRORGINCLUSAO          = $this->environment->getNrOrgTrab();
            $CDOPERULTATU   = $this->environment->getCdOperador();
            $CDOPERINCLUSAO   = $this->environment->getCdOperador();
            $DTULTATU       = $currentTime->format("d/m/Y");
            $DTINCLUSAO       = $currentTime->format("d/m/Y");
            $NRORGULTATU    = $this->environment->getNrOrgTrab();
            if(!$row['GROUPED_LABEL'] || $row['__is_new']){
                $this->TabelaPrecoService->InsertVigencia($CDTABEPREC,$DTINIVGPREC, $DTFINVGPREC, $CDOPERINCLUSAO,$DTINCLUSAO,$NRORGINCLUSAO,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU);
                $this ->TabelaPrecoService->updateTABEPREC($NMTABEPREC,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDTABEPREC);

            } else{
                $this->TabelaPrecoService->updateVigencia($CDTABEPREC,$DTINIVGPREC, $DTFINVGPREC, $OLD_DTINIVGPREC, $OLD_DTFINVGPREC ,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU);
                $this ->TabelaPrecoService->updateTABEPREC($NMTABEPREC,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDTABEPREC);
            }
        }
    }
        
        
    public function saveProduto(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
        $isNew = $row[0]['__is_new'];
        $currentTime = new \DateTime(null,new \DateTimeZone('America/Sao_Paulo'));
        $params = array(
            'IDATIVO' => 'S',
            'NRORG'          => $this->environment->getNrOrgTrab(),
            'CDOPERULTATU'   => $this->environment->getCdOperador(),
            'DTULTATU'       => $currentTime->format("d/m/Y"),
            'NRORGULTATU'    => $this->environment->getNrOrgTrab(),
            'CDTABEPREC'     => $row[0]['CDTABEPREC'],
            'DTINIVGPREC'    => $row[0]['DTINIVGPREC'],
            'VRCUSTITEM'     => $row[0]['VRCUSTITEM']   = Util::moneyToDouble($row[0]["VRCUSTITEM"]),
            'VRPRECITEM'     => $row[0]["VRPRECITEM"]   = Util::moneyToDouble($row[0]["VRPRECITEM"]),
            'VRPRESUGITEM'   => $row[0]["VRPRESUGITEM"] = Util::moneyToDouble($row[0]["VRPRESUGITEM"]),
            'VRPRECITEMCL'   => $row[0]["VRPRECITEMCL"] = Util::moneyToDouble($row[0]["VRPRECITEMCL"]),
            'IDPRECVARIA'    => $row[0]["IDPRECVARIA"] ? $row[0]["IDPRECVARIA"] : 'N',
            'IDPRODPROMOC'   => $row[0]["IDPRODPROMOC"] ? $row[0]["IDPRODPROMOC"] : 'N',
            'HRFIMVENPROD'       => $row[0]['HRFIMVENPROD'],
            'HRINIVENPROD'       => $row[0]['HRINIVENPROD'],
            'CDNVPRODUTO'       => $row[0]['DATA'][0]['CDNVPRODUTO']
        );
        
        if($isNew){
            $CDPRODUTOINI    = $row[0]['CDARVPRODINI'];
            if(!isset($row[0]['CDARVPRODFIN'])){
                $CDPRODUTOFIN    = $CDPRODUTOINI;
            }else{
                $CDPRODUTOFIN    = $row[0]['CDARVPRODFIN'];
            }
            $params = array_merge($params,array(
                'CDPRODUTOINI' => $CDPRODUTOINI,
                'CDPRODUTOFIN' => $CDPRODUTOFIN,
                'CDOPERINCLUSAO'=> $this->environment->getCdOperador(),
                'DTINCLUSAO'=> $currentTime->format("d/m/Y"),
                'NRORGINCLUSAO' => $this->environment->getNrOrgTrab()
            ));
            $data = $row[0]["DATA"];
            try{
                $result = $this->TabelaPrecoService->insertPrecoItem($params,$data);
                $response->addDataSet(new DataSet('isPlural', array('result' => $result)));
            }catch(Exception $e){
                $response->setError(new Error($e->getMessage(), 500));
            }
        }else{
            $CDPRODUTO = $CDPRPAITABPR = $row[0]['CDPRODUTO'];
            $params = array_merge($params,array(
                'CDPRODUTO' => $CDPRODUTO,
                'CDPRPAITABPR' => $CDPRPAITABPR
            ));
            try{
                $this->TabelaPrecoService->updatePrecoItem($params);
                $response->addDataSet(new DataSet('isPlural', array('result' => 1)));
            }catch(Exception $e){
                $response->setError(new Error($e->getMessage(), 500));
            }
        }
    }
    
    
    
    public function saveProdutoInlineGeral(DTO\Request $request, DTO\Response $response) {
        try {
            foreach($request->getRow() as $produto){
                $isNew = $this->TabelaPrecoService->prodExistInITEMPRECO($produto);
                if($isNew){
                    $params = self::prepareParam($produto);
                     $params = array_merge($params,array(
                        'CDPRODUTO'         =>  $produto['CDPRODUTO'],
                        'CDPRPAITABPR'      =>  $produto['CDPRODUTO']
                    ));
                    $result = $this->TabelaPrecoService->insertPrecoItemInline($params);
                } else {
                    $this->TabelaPrecoService->updatePrecoItemInline($produto['NRORG'],$produto['CDTABEPREC'],$produto['DTINIVGPREC'],$produto['CDPRODUTO'],$produto['VRPRECITEM'],$produto['VRCUSTITEM'],$produto['VRPRESUGITEM'],$produto['VRPRECITEMCL'], $produto['IDPRODPROMOC'], $produto['HRINIVENPROD'], $produto['HRFIMVENPROD']);
                }
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function prepareParam ($row){
         $currentTime = new \DateTime(null,new \DateTimeZone('America/Sao_Paulo'));
        $params = array(
            'IDATIVO' => 'S',
            'NRORG'          => $this->environment->getNrOrgTrab(),
            'CDOPERULTATU'   => $this->environment->getCdOperador(),
            'DTULTATU'       => $currentTime->format("d/m/Y"),
            'NRORGULTATU'    => $this->environment->getNrOrgTrab(),
            'CDTABEPREC'     => $row['CDTABEPREC'],
            'DTINIVGPREC'    => $row['DTINIVGPREC'],
            'VRCUSTITEM'     => $row['VRCUSTITEM']   =str_replace(',', '.', $row["VRCUSTITEM"]),
            'VRPRECITEM'     => $row["VRPRECITEM"]   =str_replace(',', '.', $row["VRPRECITEM"]),
            'VRPRESUGITEM'   => $row["VRPRESUGITEM"] =str_replace(',', '.', $row["VRPRESUGITEM"]),
            'VRPRECITEMCL'   => $row["VRPRECITEMCL"] =str_replace(',', '.', $row["VRPRECITEMCL"]),
            'IDPRECVARIA'    => $row["IDPRECVARIA"] ? $row["IDPRECVARIA"] : 'N',
            'IDPRODPROMOC'   => $row["IDPRODPROMOC"] ? $row["IDPRODPROMOC"] : 'N',
            'HRFIMVENPROD'       => $row['HRFIMVENPROD'],
            'HRINIVENPROD'       => $row['HRINIVENPROD']
        );
        return $params;
    }
    
    public function saveProdutoInlinePrecoDiferenciado(DTO\Request $request, DTO\Response $response) {
        try {
            foreach($request->getRow() as $produto){
                $produto['HRINIPRECDIA'] = str_replace(':', '', $produto['HRINIPRECDIA']);
                $produto['VRPRECODIA'] = str_replace(',', '.', $produto['VRPRECODIA']);
                $params = array(
                    ':VRPRECODIA'   =>  $produto['VRPRECODIA'],
                    ':CDTABEPREC'   =>  $produto['CDTABEPREC'],
                    ':DTINIVGPREC'  =>  $produto['DTINIVGPREC'],
                    ':CDPRODUTO'    =>  $produto['CDPRODUTO'],
                    ':NRORG'        =>  $produto['NRORG'],
                    ':CDPRPAITABPR' =>  $produto['CDPRPAITABPR'],
                    ':HRINIPRECDIA' =>  $produto['HRINIPRECDIA'],
                    ':CDTIPOCONSPD' =>  $produto['CDTIPOCONSPD'],
                    ':NRDIASEMANPR' =>  $produto['NRDIASEMANPR']
                ); 
                if($produto['IDPERVALORPR'] == 'P'){
                    if(($produto['VRPRECODIA'] <= 99.99) && ($produto['VRPRECODIA'] > 0)){
                        $this->TabelaPrecoService->updatePrecoItemInlinePrecoDiferenciado($params);
                    }
                }
                if($produto['IDPERVALORPR'] == 'V'){
                    if(($produto['VRPRECODIA'] < $produto['VRPRECITEM']) && ($produto['VRPRECODIA'] > 0)){
                        $this->TabelaPrecoService->updatePrecoItemInlinePrecoDiferenciado($params);
                    }
                }
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
   
    public function deletePrecoDiferenciado(DTO\Request $request, DTO\Response $response){
        $row = $this->util->getParamsAsArray($request);
        if(gettype($row) == 'array'){
            foreach($row as $data){
                $this->TabelaPrecoService->deletePrecosDiferenciadosDia($data);
            }
        } else {
            $this->TabelaPrecoService->deletePrecosDiferenciadosDia($row);
        }
    }
    
    public function atualizaPrecos(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $params = array(
            ':CDFILIAL'    => $row['CDFILIAL'],
            ':CDTABEPREC'  => $row['CDTABEPREC'],
            ':DTINIVGPREC' => substr($row['DTINIVGPREC'], 0, 10)
        );
        
        $this->TabelaPrecoService->updItemPrecoAtuPrec($params);
    }
    
    
    public function deleteProduto(DTO\Request $request, DTO\Response $response) {
        $row = $this->util->getParamsAsArray($request);
        
        if(gettype($row) == 'array'){
            foreach($row as $data){
                $this->TabelaPrecoService->deletePreco($data);
                $this->TabelaPrecoService->deletePrecosDiferenciados($data);
            }
        } else {
            $this->TabelaPrecoService->deletePreco($row);
            $this->TabelaPrecoService->deletePrecosDiferenciados($row);
        }
    }
    
     public function findUnidadeDisp(DTO\Request\Filter $request, DTO\Response $response) {
        
        $filterCriteria = $request->getFilterCriteria();
        $rows = $this->util->getParamsAsArray($request);
        $retorno = $this->TabelaPrecoService->findUnidadeDisp($rows);
         $response->addDataSet(new DataSet('filial_filioper_tabPrec', $retorno));

    }
  
    public function exportPriceChart(DTO\Request\Row $request, DTO\Response $response){
    // realiza rotina de Exportação da Tabela de Preço\
    
        $returnData = Array(
            'STATUS' => ''
        );
        $this->TabelaPrecoService->controlTransaction('begin');
        $backUpPRECOITEMDIA = array();
        $backUpPRECOITEM = array();
        
        
        $dataExport  = $request->getRow();
        $dataExport ['DATA'] ['DELETE_PRECODIA'] = 'S';
        $dataExport ['DATA'] ['KEEP_PRECO'] = 'S';

        //tratativa para exportar somente os valores de alguns dos produtos selecionados
        if(isset($dataExport['DATA']['CDPRODUTO'])){
            if(is_array($dataExport['DATA']['CDPRODUTO'])){
                if(count($dataExport['DATA']['CDPRODUTO']) > 0){
                    $dataExport['DATA']['TCDPRODUTO'] = null;
                }else{
                    $dataExport['DATA']['TCDPRODUTO'] = 'T';
                }
            }
        }
        $delPrecoDia = $dataExport['DATA']['DELETE_PRECODIA'] == 'S';
        $keepPreco   = $dataExport['DATA']['KEEP_PRECO'] == 'S';
        try {
            if($delPrecoDia){
                // exclui preco dif da destino
                $this->TabelaPrecoService->ExcluirPrecoDif($dataExport);
            }
            if($delPrecoDia)
                $backUpPRECOITEMDIA = $this->TabelaPrecoService->getPRECOITEMDIA($dataExport);
            if($keepPreco)
                $backUpPRECOITEM = $this->TabelaPrecoService->getPRECOITEM($dataExport);
            $returnData['STATUS'] = $this->TabelaPrecoService->exportPriceChartControl($dataExport);
            $PRECOITEMDIA = $this->TabelaPrecoService->getPRECOITEMDIA($dataExport);
            if($keepPreco){
                $this->TabelaPrecoService->setPRECOITEM($backUpPRECOITEM);
            }
            self::responseFrontEnd($response, true, $returnData);
        } catch (Exception $e) {
            $this->TabelaPrecoService->controlTransaction('rollback');
            self::responseFrontEnd($response, false, $e);
        } finally {
            $this->TabelaPrecoService->controlTransaction('commit');
        }
    }

    public function responseFrontEnd(&$response, $type, $data){
        if ($type)
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('exportPriceChart', $data));
        else
            $response->setError(new Response\Error($data->getMessage(), $data->getCode()));
    }
    
    public function findProdByTabePrecGeral(DTO\Request $request,  DTO\Response $response){
        $this->dataSourceName = 'getProdByTabePrecGeral';
        parent::find($request, $response);
    }
    
    private function valorBD($valorAplicado){
		$posVirgula = strpos( $valorAplicado, "," );
		$posPont = strpos( $valorAplicado, "." );
		
		if (!$posVirgula === false && !$posPont === false) {
			$valor = str_replace("." , "" , $valorAplicado ); // Primeiro tira os pontos
			$valorAplicado2 = str_replace(',','.',$valor);
		}else if(!$posVirgula === false && $posPont === false){
			$valorAplicado2 = str_replace(',','.',$valorAplicado);
		}else {
			$valorAplicado2 = $valorAplicado;
		}
		return $valorAplicado2;
	}
	
    
}  