<?php
    namespace Teknisa\MAN\Controllers;
    
    use Zeedhi\Framework\DTO;
    use Zeedhi\Framework\DataSource\DataSet;
    use Zeedhi\Framework\Controller\Crud;
    use Zeedhi\Framework\DataSource;
    use Zeedhi\Framework\DTO\Response\Notification;
    
    class TipoSangria extends Crud{
    
        protected $dataSourceName = 'vnd04800_tiposangria';
        
        public function save(DTO\Request\DataSet $request, DTO\Response $response) {
            try {
                $row = $request->getDataSet()->getRows()[0];
            
                $filterData = new \Zeedhi\Framework\DataSource\FilterCriteria('vnd04800_tiposangria');
                $filterData->addCondition("CDFILIAL", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDFILIAL']);
                $filterData->addCondition("CDTPSANGRIA", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['CDTPSANGRIA']);
                $filterData->addCondition("IDSANGRIA", \Zeedhi\Framework\DataSource\FilterCriteria::EQ , $row['IDSANGRIA']);
                $filterData->setDataSourceName($this->dataSourceName);
                $dataSet = $this->dataSourceManager->findBy($filterData);
                
                if(count($dataSet->getRows()) > 0 && $row['__is_new']) {
                    throw new \Exception('Essa combinação de códigos já existe no banco de dados');    
                }
                $dataSet = $request->getDataSet();
                $dataSet->setDataSourceName($this->dataSourceName);
                $persistedRows = $this->dataSourceManager->persist($dataSet);
                $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
                
            } catch (\Exception $e) {
                $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
        
        public function delete(DTO\Request\DataSet $request, DTO\Response $response) {
            try {
                if($this->isSangriaFechamento($request)){
                    throw new \Exception('O tipo de sangria padrão não pode ser excluído!');  
                }
                $dataSet = $request->getDataSet();
                $dataSet->setDataSourceName($this->dataSourceName);
                $deletedRows = $this->dataSourceManager->delete($dataSet);
                $response->addDataSet(new DataSet($this->dataSourceName, $deletedRows));
                
            } catch (\Exception $e) {
                $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
            }
        }
        
        /*
        Esse método confere se há a sangria de fechamento no sistema. 
        - Caso não tenha, ele a cria um Tipo de sangria com o código 00001 e com o nome Sangria de Fechamento. 
        - Caso tenha, não faz nada. 
        */
        
        public function find_sangriafechamento(DTO\Request\Filter $request, DTO\Response $response){
            $this->find($request, $response);
            if (empty($response->getDataSets()[0]->getRows())) {
                $cdfilial = $request->getFilterCriteria()->getConditions()[1];
                $nrorg = $request->getFilterCriteria()->getConditions()[0];
                $rowsToSave = [];
                $rowsToSave[0]['CDTPSANGRIA'] = '00001';
                $rowsToSave[0]['__is_new'] = true;
                $rowsToSave[0]['NMTPSANGRIA'] = 'Sangria de Fechamento';
                $rowsToSave[0]['CDFILIAL'] = $cdfilial['value'];
                $rowsToSave[0]['NRORG'] = $nrorg['value'];
                $rowsToSave[0]['NRORGINCLUSAO'] = $nrorg['value'];
                $rowsToSave[0]['CDOPERINCLUSAO'] = null;
                $rowsToSave[0]['DTINCLUSAO'] = null;
                $rowsToSave[0]['CDOPERULTATU'] = $nrorg['value'];
                $rowsToSave[0]['NRORGULTATU'] = null;
                $rowsToSave[0]['DTULTATU'] = null;

                $newRequest = new DTO\Request\DataSet (
                    new DataSet($this->dataSourceName, $rowsToSave) , 
                    $request->getMethod(),
                    $request->getRoutePath(),
                    $request->getUserId()
            );
               $this->save($newRequest, $response);
            }
        }
        
        /* 
        Esse método confere se o tipo de sangria a ser deletada é a de fechamento.
        - Se o código da sangria for 00001 que é a de fechamento, ele retornará true. (return true)
        - Se o código for diferente do código padrão da Sangria de Fechamento, ele retornará false. (return false)
        */
        public function isSangriaFechamento(DTO\Request\DataSet $dados){
            $permitido = false;
            $row = $dados->getDataSet()->getRows()[0];
            
            if($row['CDTPSANGRIA'] == '00001'){
                $permitido = true;
            }
            
            return $permitido;
        }
    }